==> frescobaldi_3.1.3+ds1.orig.tar.xz: frescobaldi-3.1.3/frescobaldi_app/userguide/credits.md <==
=== Credits ===

{appname} is written in {python} and uses the {qt} toolkit.

The Music View is powered by the {poppler} library by {authors} and others.

Most of the bundled icons are created by {tango}.

The following people contributed to {appname}:

!Wilbert Berendsen:
: Main author and core developer

!Christopher Bryan:
: !_(Modal Transpose)_

!Peter Bjuhr:
: !_(Quick Insert buttons for grace notes)_,
   _(MusicXML, Midi and Abc im- and export)_,
   _(Manuscript Viewer)_

!Richard Cognot:
: Kinetic Scrolling for the Music View

!Marnen Laibow-Koser:
: Homebrew formula for Mac OS X

!Davide Liessi:
: !_(Mac OS X packaging)_,
   _(various other improvements)_

!Urs Liska:
: !_(Layout control modes)_,
   _(Manuscript Viewer)_,
   _(various other contributions)_

!Nicolas Malarmey:
: Improved highlighting and auto-completion of Scheme code

!Manuel Mchalwat:
: MIDI capturing

!Mario Moles:
: Finding lots of bugs

!Pavel Roskin:
: !_(Many code and feature improvements)_,
   _(work on proper Python 3 support)_

!Alex Schreiber:
: Relative mode for MIDI capturing


{appname} is translated into the following languages:

{lang_nl}:
: !Wilbert Berendsen

{lang_fr}:
:  !Raphaël Doursenaud,
    Denis Bitouzé,
    Philippe Massart,
    Valentin Villenave,
    Yann Collette,
    David Bouriaud,
    Ryan Kavanagh,
    Richard Cognot

{lang_tr}:
:  !Server ACİM

{lang_es}:
:  !Francisco Vila

{lang_ru}:
:  !Olesya Gerasimenko,
    Sergey Poltavski,
    Artem Zolochevskiy,
    Mikhail Iglizky,
    Pavel Roskin

{lang_it}:
:  !Gianluca D'Orazio,
    Federico Bruni,
    Davide Liessi

{lang_de}:
:  !Henrik Evers,
    Georg Hennig,
    Markus W. Kropp,
    Urs Liska,
    Henning Hraban Ramm

{lang_sv}:
:  !Dag Odenhall

{lang_cs}:
:  !Pavel Fric

{lang_pl}:
:  !Piotr Komorowski

{lang_gl}:
:  !Manuel A. Vázquez

{lang_pt_br}:
:  !Édio Mazera,
    Arnaldo Russo

{lang_uk}:
:  !Dmytro O. Redchuk

{lang_zh}:
:  !Anthony Fok

And of course, a big *Thank You* goes to the LilyPond developers, who create
such an excellent music engraver!


#VARS
python md [http://www.python.org/ Python]
qt md [http://www.qt.io/ Qt]
poppler md [http://poppler.freedesktop.org/ Poppler]
authors text Kristian Høgsberg, Albert Astals Cid
tango md [http://tango.freedesktop.org/ The Tango Desktop Project]
lang_cs     languagename cs
lang_de     languagename de
lang_es     languagename es
lang_fr     languagename fr
lang_gl     languagename gl
lang_it     languagename it
lang_nl     languagename nl
lang_pl     languagename pl
lang_pt_br  languagename pt_BR
lang_ru     languagename ru
lang_tr     languagename tr
lang_sv     languagename sv
lang_uk     languagename uk
lang_zh     languagename zh

==> frescobaldi_3.3.0+ds1.orig.tar.xz: frescobaldi-3.3.0/frescobaldi_app/userguide/credits.md <==
=== Credits ===

{appname} is written in {python} and uses the {qt} toolkit.

The Music View is powered by the {poppler} library by {authors} and others.

Most of the bundled icons are created by {tango}.

The following people contributed to {appname} (in alphabetical order):

!Jean Abou Samra
: Bug and compatibility fixes, miscellaneous

!Wilbert Berendsen:
: Main author and core developer

!@mr-bronson
: Encoding-related fixes and other improvements

!Christopher Bryan:
: !_(Modal Transpose)_

!Peter Bjuhr:
: !_(Quick Insert buttons for grace notes)_,
   _(MusicXML, MIDI and ABC im- and export)_,
   _(Manuscript Viewer)_

!Richard Cognot:
: Kinetic Scrolling for the Music View

!Benjamin Johnson:
: !_(Score Wizard improvements)_,
  _(Score Wizard From Current Document)_

!Jörg Hoffmann
: Windows installers

!Marnen Laibow-Koser:
: Homebrew formula for macOS

!Davide Liessi:
: !macOS packaging,
   _(various other improvements)_

!Urs Liska:
: !_(Layout control modes)_,
   _(Manuscript Viewer)_,
   _(various other contributions)_

!Nicolas Malarmey:
: Improved highlighting and auto-completion of Scheme code

!Manuel Mchalwat:
: MIDI capturing

!Jacques Menu:
: macOS installers (arm64)

!Mario Moles:
: Finding lots of bugs

!Pavel Roskin:
: !_(Many code and feature improvements)_,
   _(work on proper Python 3 support)_

!Alex Schreiber:
: Relative mode for MIDI capturing


{appname} is translated into the following languages:

{lang_nl}:
: !Wilbert Berendsen

{lang_fr}:
:  !Rémy Claverie,
    Denis Bitouzé,
    David Bouriaud,
    Richard Cognot,
    Yann Collette,
    Raphaël Doursenaud,
    Emmanuel Franquemagne,
    Raphaël Hardy,
    Ryan Kavanagh,
    Nicolas Lehembre,
    Philippe Massart,
    Olivier Miakinen,
    Martial Rameaux,
    Valentin Villenave

{lang_tr}:
:  !Server ACİM

{lang_es}:
:  !Francisco Vila

{lang_ru}:
:  !Olesya Gerasimenko,
    Sergey Poltavski,
    Artem Zolochevskiy,
    Mikhail Iglizky,
    Pavel Roskin

{lang_it}:
:  !Gianluca D'Orazio,
    Federico Bruni,
    Davide Liessi

{lang_de}:
:  !Henrik Evers,
    Georg Hennig,
    Markus W. Kropp,
    Urs Liska,
    Henning Hraban Ramm

{lang_sv}:
:  !Dag Odenhall

{lang_cs}:
:  !Pavel Fric

{lang_pl}:
:  !Piotr Komorowski

{lang_gl}:
:  !Manuel A. Vázquez

{lang_pt_br}:
:  !Édio Mazera,
    Arnaldo Russo

{lang_uk}:
:  !Dmytro O. Redchuk

{lang_zh}:
:  !Anthony Fok

{lang_ja}:
:  !Jun Tamura

And of course, a big *Thank You* goes to the LilyPond developers, who create
such an excellent music engraver!


#VARS
python md [http://www.python.org/ Python]
qt md [http://www.qt.io/ Qt]
poppler md [http://poppler.freedesktop.org/ Poppler]
authors text Kristian Høgsberg, Albert Astals Cid
tango md [http://tango.freedesktop.org/ The Tango Desktop Project]
lang_cs     languagename cs
lang_de     languagename de
lang_es     languagename es
lang_fr     languagename fr
lang_gl     languagename gl
lang_it     languagename it
lang_ja     languagename ja
lang_nl     languagename nl
lang_pl     languagename pl
lang_pt_br  languagename pt_BR
lang_ru     languagename ru
lang_tr     languagename tr
lang_sv     languagename sv
lang_uk     languagename uk
lang_zh     languagename zh
